ADJECTIVES = [
    "aristotelian",
    "arthurian",
    "bohemian",
    "brethren",
    "mosaic",
    "pceanic",
    "proctor",
    "terran",
    "tudor",
    "abroad",
    "absorbing",
    "abstract",
    "academic",
    "accelerated",
    "accented",
    "accountant",
    "acquainted",
    "acute",
    "addicting",
    "addictive",
    "adjustable",
    "admired",
    "adult",
    "adverse",
    "advised",
    "aerosol",
    "afraid",
    "aggravated",
    "aggressive",
    "agreeable",
    "alienate",
    "aligned",
    "alleged",
    "almond",
    "alright",
    "altruistic",
    "ambient",
    "ambivalent",
    "amiable",
    "amino",
    "amorphous",
    "amused",
    "anatomical",
    "ancestral",
    "angelic",
    "angrier",
    "answerable",
    "antiquarian",
    "antiretroviral",
    "appellate",
    "applicable",
    "apportioned",
    "approachable",
    "appropriated",
    "archer",
    "aroused",
    "arrested",
    "assertive",
    "assigned",
    "athletic",
    "atrocious",
    "attained",
    "authoritarian",
    "autobiographical",
    "avaricious",
    "avocado",
    "awake",
    "awsome",
    "backstage",
    "backwoods",
    "balding",
    "bandaged",
    "banded",
    "banned",
    "barreled",
    "battle",
    "beaten",
    "begotten",
    "beguiled",
    "bellied",
    "belted",
    "beneficent",
    "besieged",
    "betting",
    "biggest",
    "biochemical",
    "bipolar",
    "blackened",
    "blame",
    "blessed",
    "blindfolded",
    "bloat",
    "blocked",
    "blooded",
    "blushing",
    "boastful",
    "bolder",
    "bolstered",
    "bonnie",
    "bored",
    "boundary",
    "bounded",
    "bounding",
    "branched",
    "brawling",
    "brazen",
    "breeding",
    "bridged",
    "brimming",
    "brimstone",
    "broadest",
    "broiled",
    "broker",
    "bronze",
    "bruising",
    "buffy",
    "bullied",
    "bungling",
    "burial",
    "buttery",
    "candied",
    "canonical",
    "cantankerous",
    "cardinal",
    "carefree",
    "caretaker",
    "casual",
    "cathartic",
    "causal",
    "chapel",
    "characterized",
    "charcoal",
    "cheeky",
    "cherished",
    "chipotle",
    "chirping",
    "chivalrous",
    "circumstantial",
    "civic",
    "civil",
    "civilised",
    "clanking",
    "clapping",
    "claptrap",
    "classless",
    "cleansed",
    "cleric",
    "cloistered",
    "codified",
    "colloquial",
    "colour",
    "combat",
    "combined",
    "comely",
    "commissioned",
    "commonplace",
    "commuter",
    "commuting",
    "comparable",
    "complementary",
    "compromising",
    "conceding",
    "concentrated",
    "conceptual",
    "conditioned",
    "confederate",
    "confident",
    "confidential",
    "confining",
    "confuse",
    "congressional",
    "consequential",
    "conservative",
    "constituent",
    "contaminated",
    "contemporaneous",
    "contraceptive",
    "convertible",
    "convex",
    "cooked",
    "coronary",
    "corporatist",
    "correlated",
    "corroborated",
    "cosmic",
    "cover",
    "crash",
    "crypto",
    "culminate",
    "cushioned",
    "dandy",
    "dashing",
    "dazzled",
    "decreased",
    "decrepit",
    "dedicated",
    "defaced",
    "defective",
    "defenseless",
    "deluded",
    "deodorant",
    "departed",
    "depress",
    "designing",
    "despairing",
    "destitute",
    "detective",
    "determined",
    "devastating",
    "deviant",
    "devilish",
    "devoted",
    "diagonal",
    "dictated",
    "didactic",
    "differentiated",
    "diffused",
    "dirtier",
    "disabling",
    "disconnected",
    "discovered",
    "disdainful",
    "diseased",
    "disfigured",
    "disheartened",
    "disheveled",
    "disillusioned",
    "disparate",
    "dissident",
    "doable",
    "doctrinal",
    "doing",
    "dotted",
    "downbeat",
    "dozen",
    "draining",
    "draught",
    "dread",
    "dried",
    "dropped",
    "dulled",
    "duplicate",
    "eaten",
    "echoing",
    "economical",
    "elaborated",
    "elastic",
    "elective",
    "electoral",
    "elven",
    "embryo",
    "emerald",
    "emergency",
    "emissary",
    "emotional",
    "employed",
    "enamel",
    "encased",
    "encrusted",
    "endangered",
    "engraved",
    "engrossing",
    "enlarged",
    "enlisted",
    "enlivened",
    "ensconced",
    "entangled",
    "enthralling",
    "entire",
    "envious",
    "eradicated",
    "eroded",
    "esoteric",
    "essential",
    "evaporated",
    "evergreen",
    "everlasting",
    "exacting",
    "exasperated",
    "excess",
    "exciting",
    "executable",
    "existent",
    "exonerated",
    "exorbitant",
    "exponential",
    "export",
    "extraordinary",
    "exultant",
    "exulting",
    "facsimile",
    "fading",
    "fainter",
    "fallacious",
    "faltering",
    "famous",
    "fancier",
    "fated",
    "favourable",
    "fearless",
    "feathered",
    "fellow",
    "fermented",
    "ferocious",
    "fiddling",
    "filling",
    "firmer",
    "fitted",
    "flammable",
    "flawed",
    "fledgling",
    "fleshy",
    "flexible",
    "flickering",
    "floral",
    "flowering",
    "flowing",
    "foggy",
    "folic",
    "foolhardy",
    "foolish",
    "footy",
    "forehand",
    "forked",
    "formative",
    "formulaic",
    "fractional",
    "fragrant",
    "fraudulent",
    "freakish",
    "freckled",
    "freelance",
    "freight",
    "fresh",
    "fretted",
    "frugal",
    "fulfilling",
    "fuming",
    "funded",
    "funny",
    "garbled",
    "gathered",
    "geologic",
    "geometric",
    "gibberish",
    "gilded",
    "ginger",
    "glare",
    "glaring",
    "gleaming",
    "glorified",
    "glorious",
    "goalless",
    "goody",
    "grammatical",
    "grande",
    "grateful",
    "gratuitous",
    "graven",
    "greener",
    "grinding",
    "grizzly",
    "groaning",
    "grudging",
    "guaranteed",
    "gusty",
    "halfbreed",
    "handheld",
    "handheld",
    "handsoff",
    "hardpressed",
    "harlot",
    "healing",
    "healthier",
    "healthiest",
    "heart",
    "heartshaped",
    "heathen",
    "hedonistic",
    "heralded",
    "herbal",
    "highdensity",
    "highperformance",
    "highres",
    "highyield",
    "hissy",
    "hitless",
    "holiness",
    "homesick",
    "honorable",
    "hooded",
    "hopeless",
    "horrendous",
    "horrible",
    "hotbutton",
    "huddled",
    "human",
    "humbling",
    "humid",
    "humiliating",
    "hypnotized",
    "idealistic",
    "idiosyncratic",
    "ignited",
    "illustrated",
    "illustrative",
    "imitated",
    "immense",
    "immersive",
    "immigrant",
    "immoral",
    "impassive",
    "impressionable",
    "improbable",
    "impulsive",
    "in-flight",
    "inattentive",
    "inbound",
    "inbounds",
    "incalculable",
    "incomprehensible",
    "indefatigable",
    "indigo",
    "indiscriminate",
    "indomitable",
    "inert",
    "inflate",
    "inform",
    "inheriting",
    "injured",
    "injurious",
    "inking",
    "inoffensive",
    "insane",
    "insensible",
    "insidious",
    "insincere",
    "insistent",
    "insolent",
    "insufferable",
    "intemperate",
    "interdependent",
    "interesting",
    "interfering",
    "intern",
    "interpreted",
    "intersecting",
    "intolerable",
    "intolerant",
    "intuitive",
    "irresolute",
    "irritate",
    "jealous",
    "jerking",
    "joining",
    "joint",
    "journalistic",
    "joyful",
    "keyed",
    "knowing",
    "lacklustre",
    "laden",
    "lagging",
    "lamented",
    "laughable",
    "layered",
    "leather",
    "leathern",
    "leery",
    "legible",
    "leisure",
    "lessening",
    "liberating",
    "lifesize",
    "lifted",
    "lightest",
    "limitless",
    "listening",
    "literary",
    "liver",
    "livid",
    "lobster",
    "locked",
    "longheld",
    "longlasting",
    "longrunning",
    "longsuffering",
    "loudest",
    "loveliest",
    "lowbudget",
    "lowcarb",
    "lowering",
    "lucid",
    "luckless",
    "lusty",
    "luxurious",
    "magazine",
    "maniac",
    "manmade",
    "maroon",
    "mastered",
    "mated",
    "material",
    "materialistic",
    "meaningful",
    "measuring",
    "mediaeval",
    "medical",
    "meditated",
    "medley",
    "melodic",
    "memorable",
    "memorial",
    "metabolic",
    "metallic",
    "metallurgical",
    "metering",
    "midair",
    "midterm",
    "midway",
    "mighty",
    "migrating",
    "mindblowing",
    "mindboggling",
    "minor",
    "mirrored",
    "misguided",
    "misshapen",
    "mitigated",
    "mixed",
    "modernized",
    "molecular",
    "monarch",
    "monastic",
    "morbid",
    "motley",
    "motorized",
    "mounted",
    "multidisciplinary",
    "muscled",
    "muscular",
    "muted",
    "mysterious",
    "mythic",
    "nailbiting",
    "natural",
    "nauseous",
    "negative",
    "networked",
    "neurological",
    "neutered",
    "newest",
    "night",
    "nitrous",
    "nofly",
    "noncommercial",
    "nonsense",
    "north",
    "nuanced",
    "occurring",
    "offensive",
    "oldest",
    "oncoming",
    "one-year",
    "onstage",
    "onward",
    "opaque",
    "operating",
    "opportunist",
    "opposing",
    "ordinate",
    "outdone",
    "outlaw",
    "outsized",
    "overboard",
    "overheated",
    "oversize",
    "overworked",
    "oyster",
    "paced",
    "panting",
    "paralyzed",
    "paramount",
    "parental",
    "parted",
    "partisan",
    "passive",
    "pastel",
    "patriot",
    "peacekeeping",
    "pedestrian",
    "peevish",
    "penal",
    "penned",
    "pensive",
    "perceptual",
    "perky",
    "permissible",
    "pernicious",
    "perpetuate",
    "perplexed",
    "pervasive",
    "petrochemical",
    "philosophical",
    "picturesque",
    "pillaged",
    "piped",
    "piquant",
    "pitching",
    "plausible",
    "pliable",
    "plumb",
    "politician",
    "polygamous",
    "poorest",
    "portmanteau",
    "posed",
    "positive",
    "possible",
    "postpartum",
    "prank",
    "precocious",
    "predicted",
    "premium",
    "preparatory",
    "prerequisite",
    "prescient",
    "preserved",
    "presidential",
    "pressed",
    "pressurized",
    "presumed",
    "prewar",
    "priced",
    "pricier",
    "primal",
    "primer",
    "primetime",
    "printed",
    "private",
    "problem",
    "procedural",
    "process",
    "prodigious",
    "professional",
    "programmed",
    "progressive",
    "prolific",
    "promising",
    "promulgated",
    "pronged",
    "proportionate",
    "protracted",
    "pulled",
    "pulsed",
    "purgatory",
    "quick",
    "raunchy",
    "razed",
    "reactive",
    "readable",
    "realizing",
    "recognised",
    "recovering",
    "recurrent",
    "recycled",
    "redeemable",
    "reflecting",
    "regal",
    "registering",
    "reliable",
    "reminiscent",
    "remorseless",
    "removable",
    "renewable",
    "repeating",
    "repellent",
    "reserve",
    "resigned",
    "respectful",
    "rested",
    "restrict",
    "resultant",
    "retaliatory",
    "retiring",
    "revelatory",
    "reverend",
    "reversing",
    "revolving",
    "ridiculous",
    "ringed",
    "risque",
    "robust",
    "roomful",
    "rotating",
    "roused",
    "rubber",
    "running",
    "runtime",
    "rustling",
    "safest",
    "salient",
    "sanctioned",
    "saute",
    "saved",
    "scandalized",
    "scarlet",
    "scattering",
    "sceptical",
    "scheming",
    "scoundrel",
    "scratched",
    "scratchy",
    "scrolled",
    "seated",
    "secondbest",
    "segregated",
    "selftaught",
    "semiautomatic",
    "senior",
    "sensed",
    "sentient",
    "sexier",
    "shadowy",
    "shaken",
    "shaker",
    "shameless",
    "shaped",
    "shiny",
    "shipped",
    "shivering",
    "shoestring",
    "short",
    "shortlived",
    "signed",
    "simplest",
    "simplistic",
    "sizable",
    "skeleton",
    "skinny",
    "skirting",
    "skyrocketed",
    "slamming",
    "slanting",
    "slapstick",
    "sleek",
    "sleepless",
    "sleepy",
    "slender",
    "slimmer",
    "smacking",
    "smokeless",
    "smothered",
    "smouldering",
    "snuff",
    "socialized",
    "solidstate",
    "sometime",
    "sought",
    "spanking",
    "sparing",
    "spattered",
    "specialized",
    "specific",
    "speedy",
    "spherical",
    "spiky",
    "spineless",
    "sprung",
    "squint",
    "stainless",
    "standing",
    "starlight",
    "startled",
    "stately",
    "statewide",
    "stereoscopic",
    "sticky",
    "stimulant",
    "stinky",
    "stoked",
    "stolen",
    "storied",
    "strained",
    "strapping",
    "strengthened",
    "stubborn",
    "stylized",
    "suave",
    "subjective",
    "subjugated",
    "subordinate",
    "succeeding",
    "suffering",
    "summary",
    "sunset",
    "sunshine",
    "supernatural",
    "supervisory",
    "supplyside",
    "surrogate",
    "suspended",
    "suspenseful",
    "swarthy",
    "sweating",
    "sweeping",
    "swinging",
    "swooning",
    "sympathize",
    "synchronized",
    "synonymous",
    "synthetic",
    "tailed",
    "tallest",
    "tangible",
    "tanked",
    "tarry",
    "technical",
    "tectonic",
    "telepathic",
    "tenderest",
    "territorial",
    "testimonial",
    "theistic",
    "thicker",
    "threatening",
    "tightlipped",
    "timed",
    "timely",
    "timid",
    "torrent",
    "totalled",
    "tougher",
    "traditional",
    "transformed",
    "trapped",
    "traveled",
    "traverse",
    "treated",
    "trial",
    "trunk",
    "trusting",
    "trying",
    "twisted",
    "twolane",
    "tyrannical",
    "unaided",
    "unassisted",
    "unassuming",
    "unattractive",
    "uncapped",
    "uncomfortable",
    "uncontrolled",
    "uncooked",
    "uncooperative",
    "underground",
    "undersea",
    "undisturbed",
    "unearthly",
    "uneasy",
    "unequal",
    "unfazed",
    "unfinished",
    "unforeseen",
    "unforgivable",
    "unidentified",
    "unimaginative",
    "uninspired",
    "unintended",
    "uninvited",
    "universal",
    "unmasked",
    "unorthodox",
    "unparalleled",
    "unpleasant",
    "unprincipled",
    "unread",
    "unreasonable",
    "unregulated",
    "unreliable",
    "unremitting",
    "unsafe",
    "unsanitary",
    "unsealed",
    "unsuccessful",
    "unsupervised",
    "untimely",
    "unwary",
    "unwrapped",
    "uppity",
    "upstart",
    "useless",
    "utter",
    "valiant",
    "valid",
    "valued",
    "vanilla",
    "vaulting",
    "vaunted",
    "veering",
    "vegetative",
    "vented",
    "verbal",
    "verifying",
    "veritable",
    "versed",
    "vinyl",
    "virgin",
    "visceral",
    "visual",
    "voluptuous",
    "walkon",
    "wanton",
    "warlike",
    "washed",
    "waterproof",
    "waved",
    "weakest",
    "wellbred",
    "wellchosen",
    "wellinformed",
    "wetting",
    "wheeled",
    "whirlwind",
    "widen",
    "widening",
    "willful",
    "willing",
    "winnable",
    "winningest",
    "wireless",
    "wistful",
    "woeful",
    "wooded",
    "woodland",
    "wordless",
    "workable",
    "worldly",
    "worldwide",
    "worstcase",
    "worsted",
    "worthless",
    "abandoned",
    "abused",
    "accepted",
    "accomplished",
    "accusatory",
    "accused",
    "adored",
    "adrift",
    "affectionate",
    "agitated",
    "alarmed",
    "alert",
    "alienated",
    "alive",
    "alluring",
    "alone",
    "aloof",
    "amazed",
    "ambushed",
    "angry",
    "annoyed",
    "antagonistic",
    "anxious",
    "apathetic",
    "apologetic",
    "appalled",
    "appreciated",
    "appreciative",
    "apprehensive",
    "ashamed",
    "astonished",
    "attacked",
    "attractive",
    "aware",
    "awe",
    "awed",
    "awestruck",
    "awkward",
    "bad",
    "baffled",
    "barren",
    "bashful",
    "belittled",
    "benevolent",
    "berated",
    "betrayed",
    "bewildered",
    "bitchy",
    "bitter",
    "bittersweet",
    "blah",
    "blamed",
    "blank",
    "blissful",
    "blue",
    "bold",
    "bothered",
    "bouncy",
    "brave",
    "broken",
    "brooding",
    "bummed",
    "burdened",
    "burned",
    "callous",
    "calm",
    "capable",
    "careless",
    "caring",
    "caustic",
    "cautious",
    "censored",
    "centered",
    "certain",
    "challenged",
    "charmed",
    "cheated",
    "cheerful",
    "childish",
    "chipper",
    "choleric",
    "clean",
    "clear",
    "clever",
    "close",
    "closed",
    "clueless",
    "clumsy",
    "cold",
    "comfortable",
    "committed",
    "compassionate",
    "competent",
    "competitive",
    "complacent",
    "complete",
    "concerned",
    "condemned",
    "condescension",
    "confused",
    "considerate",
    "contemplative",
    "contempt",
    "contemptuous",
    "content",
    "controlled",
    "conventional",
    "convicted",
    "cornered",
    "courageous",
    "cowardly",
    "cranky",
    "crappy",
    "crazy",
    "critical",
    "cross",
    "crushed",
    "curious",
    "cynical",
    "daring",
    "dark",
    "dashed",
    "dazed",
    "dead",
    "deceived",
    "defeated",
    "defensive",
    "defiant",
    "degraded",
    "dejected",
    "delicate",
    "delighted",
    "demoralized",
    "dependent",
    "depressed",
    "deprived",
    "derisive",
    "deserted",
    "desired",
    "desolate",
    "despair",
    "desperate",
    "destroyed",
    "detached",
    "devastated",
    "devious",
    "different",
    "difficult",
    "dignified",
    "dirty",
    "disappointed",
    "disbelieving",
    "discarded",
    "discontent",
    "discontented",
    "discouraged",
    "disgraced",
    "disgusted",
    "dishonest",
    "dismal",
    "dismayed",
    "disobedient",
    "disorganized",
    "disposable",
    "distant",
    "distracted",
    "distressed",
    "disturbed",
    "ditzy",
    "dorky",
    "doubtful",
    "down",
    "drained",
    "dreamy",
    "dreary",
    "drunk",
    "dull",
    "dumb",
    "eager",
    "earnest",
    "ecstatic",
    "edgy",
    "effective",
    "elated",
    "embarassed",
    "embarrassed",
    "empathetic",
    "empowered",
    "empty",
    "enchanted",
    "encouraged",
    "energetic",
    "energized",
    "enlightened",
    "enraged",
    "enriched",
    "entertained",
    "enthralled",
    "enthusiastic",
    "erudite",
    "evasive",
    "evil",
    "excited",
    "excluded",
    "exhausted",
    "exhilarated",
    "expectant",
    "exploited",
    "exposed",
    "exuberant",
    "faithful",
    "fake",
    "fanciful",
    "fantastic",
    "fatalistic",
    "fatigued",
    "fearful",
    "feisty",
    "fine",
    "flirty",
    "flustered",
    "foreboding",
    "forgiven",
    "forgiving",
    "forgotten",
    "forthright",
    "fortunate",
    "framed",
    "frantic",
    "free",
    "friendly",
    "frightened",
    "frisky",
    "frustrated",
    "fulfilled",
    "full",
    "furious",
    "futile",
    "geeky",
    "generous",
    "gentle",
    "giddy",
    "giggly",
    "giving",
    "glad",
    "gloomy",
    "good",
    "great",
    "grieving",
    "groggy",
    "grouchy",
    "grumpy",
    "guarded",
    "guilty",
    "gullible",
    "handicapped",
    "happy",
    "harmonious",
    "hateful",
    "haughty",
    "haunted",
    "haunting",
    "healthy",
    "heard",
    "heartbroken",
    "helpful",
    "helpless",
    "hesitant",
    "high",
    "honored",
    "hopeful",
    "horrified",
    "hospitable",
    "hostile",
    "hot",
    "humble",
    "humiliated",
    "hungry",
    "hurt",
    "hyper",
    "hysterical",
    "idiotic",
    "idyllic",
    "ignorant",
    "ignored",
    "imaginative",
    "immune",
    "impatient",
    "impelled",
    "imperfect",
    "impertinent",
    "important",
    "impressed",
    "inadequate",
    "incensed",
    "inclusive",
    "incompetent",
    "incomplete",
    "incredulous",
    "indebted",
    "indecisive",
    "independent",
    "indescribable",
    "indifferent",
    "indignant",
    "industrious",
    "inept",
    "inferior",
    "inflated",
    "informed",
    "infuriated",
    "inhibited",
    "innocent",
    "innovative",
    "inquisitive",
    "insecure",
    "insensitive",
    "insignificant",
    "insulted",
    "intense",
    "interested",
    "interrogated",
    "interrupted",
    "intimate",
    "intimidated",
    "intrigued",
    "invigorated",
    "invisible",
    "involved",
    "irate",
    "irked",
    "irrational",
    "irresponsible",
    "irritated",
    "isolated",
    "jaded",
    "jinxed",
    "jolly",
    "jovial",
    "joyous",
    "jubilant",
    "judged",
    "judgmental",
    "jumpy",
    "just",
    "justified",
    "kidded",
    "kind",
    "knowledgeable",
    "late",
    "lazy",
    "left",
    "let",
    "lethargic",
    "liable",
    "liberated",
    "lifeless",
    "liked",
    "listened",
    "listless",
    "logical",
    "lonely",
    "loose",
    "lost",
    "lousy",
    "lovable",
    "loved",
    "loving",
    "lucky",
    "lyrical",
    "mad",
    "malicious",
    "manipulated",
    "matter",
    "fact",
    "mean",
    "meditative",
    "melancholic",
    "melancholy",
    "mellow",
    "merciless",
    "merry",
    "mischievous",
    "miserable",
    "misinterpreted",
    "mistreated",
    "misunderstood",
    "mocked",
    "mocking",
    "modest",
    "molested",
    "moody",
    "morose",
    "motivated",
    "mournful",
    "moved",
    "mystified",
    "naive",
    "nasty",
    "naughty",
    "nauseated",
    "needed",
    "needy",
    "neglected",
    "nerdy",
    "nervous",
    "neurotic",
    "nightmarish",
    "nonchalant",
    "nostalgic",
    "not",
    "specified",
    "noticed",
    "numb",
    "obeyed",
    "objective",
    "obligated",
    "obvious",
    "odd",
    "offended",
    "okay",
    "old",
    "open",
    "oppressed",
    "optimistic",
    "ornery",
    "control",
    "outraged",
    "overcome",
    "overjoyed",
    "overloaded",
    "overwhelmed",
    "owned",
    "painful",
    "pampered",
    "panicky",
    "passionate",
    "patient",
    "patronizing",
    "peaceful",
    "peeved",
    "persecuted",
    "pessimistic",
    "pestered",
    "petrified",
    "petty",
    "phony",
    "pious",
    "pissed",
    "off",
    "playful",
    "pleased",
    "poor",
    "possessive",
    "powerful",
    "powerless",
    "practical",
    "predatory",
    "pressured",
    "productive",
    "protected",
    "protective",
    "proud",
    "provoked",
    "prudish",
    "punished",
    "pushy",
    "puzzled",
    "questioned",
    "quiet",
    "quixotic",
    "quizzical",
    "rambunctious",
    "realistic",
    "reassured",
    "rebellious",
    "reborn",
    "receptive",
    "reckless",
    "recognized",
    "reconciled",
    "recumbent",
    "reflective",
    "refreshed",
    "regretful",
    "rejected",
    "rejuvenated",
    "relaxed",
    "released",
    "relieved",
    "reluctant",
    "remorse",
    "renewed",
    "replaced",
    "replenished",
    "repressed",
    "rescued",
    "resentful",
    "reserved",
    "resistant",
    "resourceful",
    "respected",
    "responsible",
    "restless",
    "restricted",
    "revengeful",
    "reverent",
    "revitalized",
    "ribald",
    "rich",
    "ridicule",
    "right",
    "rigid",
    "robbed",
    "romantic",
    "rotten",
    "rushed",
    "sabotaged",
    "sad",
    "safe",
    "sarcastic",
    "sardonic",
    "sassy",
    "satiated",
    "satiric",
    "satisfied",
    "scared",
    "scolded",
    "scorned",
    "secure",
    "seductive",
    "selfish",
    "self-centered",
    "self-conscious",
    "self-reliant",
    "sensitive",
    "sentimental",
    "serene",
    "serious",
    "sexy",
    "shamed",
    "sheepish",
    "shocked",
    "shunned",
    "shy",
    "sick",
    "silenced",
    "silly",
    "sincere",
    "sinful",
    "skeptical",
    "skillful",
    "slandered",
    "sluggish",
    "small",
    "smart",
    "solemn",
    "somber",
    "soothed",
    "sorry",
    "special",
    "spiteful",
    "splendid",
    "spunky",
    "squashed",
    "stifled",
    "stimulated",
    "stingy",
    "stressed",
    "stretched",
    "strong",
    "stumped",
    "stunned",
    "stupid",
    "submissive",
    "successful",
    "suffocated",
    "suicidal",
    "sullen",
    "sunk",
    "super",
    "superior",
    "supported",
    "sure",
    "surly",
    "surprised",
    "suspicious",
    "sympathetic",
    "tacky",
    "tactful",
    "talented",
    "talkative",
    "tame",
    "tarnished",
    "tasteful",
    "tearful",
    "teased",
    "tenacious",
    "tender",
    "tense",
    "tepid",
    "terrible",
    "terrific",
    "terrified",
    "terrifying",
    "tested",
    "testy",
    "thankful",
    "thoughtful",
    "threatened",
    "thrifty",
    "thrilled",
    "tired",
    "tormented",
    "torn",
    "tortured",
    "touched",
    "tough",
    "tragic",
    "tranquil",
    "treasured",
    "trembly",
    "tremendous",
    "tricked",
    "troubled",
    "trusted",
    "trustful",
    "ugly",
    "unaccepted",
    "unappreciated",
    "unbalanced",
    "unburdened",
    "uncanny",
    "unconcerned",
    "uneven",
    "unfit",
    "unfriendly",
    "united",
    "unjust",
    "unknown",
    "unneeded",
    "unreal",
    "unruly",
    "unwise",
    "up",
    "uplifted",
    "used",
    "vacant",
    "vague",
    "vain",
    "vengeful",
    "vexed",
    "vicious",
    "victimized",
    "victorious",
    "violated",
    "violent",
    "vivacious",
    "vivid",
    "void",
    "wacky",
    "warm",
    "warmhearted",
    "warned",
    "wary",
    "wasted",
    "weak",
    "wealthy",
    "weary",
    "weird",
    "welcoming",
    "whimsical",
    "whole",
    "wild",
    "wishful",
    "witty",
    "worried",
    "worse",
    "worthy",
    "wounded",
    "wrong",
    "yearning",
    "yellow",
    "yielding",
    "young",
    "youthful",
    "zany",
    "zealous"
]

MOODS = [
    "abandoned",
    "abused",
    "accepted",
    "accomplished",
    "accusatory",
    "accused",
    "admired",
    "adored",
    "adrift",
    "affectionate",
    "afraid",
    "aggravated",
    "aggressive",
    "agitated",
    "alarmed",
    "alert",
    "alienated",
    "alive",
    "alluring",
    "alone",
    "aloof",
    "amazed",
    "ambushed",
    "amused",
    "angry",
    "annoyed",
    "antagonistic",
    "anxious",
    "apathetic",
    "apologetic",
    "appalled",
    "appreciated",
    "appreciative",
    "apprehensive",
    "aroused",
    "ashamed",
    "astonished",
    "attacked",
    "attractive",
    "awake",
    "aware",
    "awe",
    "awed",
    "awestruck",
    "awkward",
    "bad",
    "baffled",
    "barren",
    "bashful",
    "beaten",
    "belittled",
    "benevolent",
    "berated",
    "betrayed",
    "bewildered",
    "bitchy",
    "bitter",
    "bittersweet",
    "blah",
    "blamed",
    "blank",
    "blissful",
    "blue",
    "bold",
    "bored",
    "bothered",
    "bouncy",
    "brave",
    "broken",
    "brooding",
    "bummed",
    "burdened",
    "burned",
    "callous",
    "calm",
    "capable",
    "carefree",
    "careless",
    "caring",
    "caustic",
    "cautious",
    "censored",
    "centered",
    "certain",
    "challenged",
    "charmed",
    "cheated",
    "cheerful",
    "cherished",
    "childish",
    "chipper",
    "choleric",
    "clean",
    "clear",
    "clever",
    "close",
    "closed",
    "clueless",
    "clumsy",
    "cold",
    "comfortable",
    "committed",
    "compassionate",
    "competent",
    "competitive",
    "complacent",
    "complete",
    "concerned",
    "condemned",
    "condescension",
    "confident",
    "confining",
    "confused",
    "considerate",
    "contemplative",
    "contempt",
    "contemptuous",
    "content",
    "controlled",
    "conventional",
    "convicted",
    "cornered",
    "courageous",
    "cowardly",
    "cranky",
    "crappy",
    "crazy",
    "critical",
    "cross",
    "crushed",
    "curious",
    "cynical",
    "daring",
    "dark",
    "dashed",
    "dazed",
    "dead",
    "deceived",
    "dedicated",
    "defeated",
    "defenseless",
    "defensive",
    "defiant",
    "degraded",
    "dejected",
    "delicate",
    "delighted",
    "demoralized",
    "dependent",
    "depressed",
    "deprived",
    "derisive",
    "deserted",
    "desired",
    "desolate",
    "despair",
    "desperate",
    "destroyed",
    "detached",
    "determined",
    "devastated",
    "devious",
    "devoted",
    "didactic",
    "different",
    "difficult",
    "dignified",
    "dirty",
    "disappointed",
    "disbelieving",
    "discarded",
    "disconnected",
    "discontent",
    "discontented",
    "discouraged",
    "disdainful",
    "disgraced",
    "disgusted",
    "disheartened",
    "dishonest",
    "disillusioned",
    "dismal",
    "dismayed",
    "disobedient",
    "disorganized",
    "disposable",
    "distant",
    "distracted",
    "distressed",
    "disturbed",
    "ditzy",
    "dorky",
    "doubtful",
    "down",
    "drained",
    "dreamy",
    "dreary",
    "dropped",
    "drunk",
    "dull",
    "dumb",
    "eager",
    "earnest",
    "ecstatic",
    "edgy",
    "effective",
    "elated",
    "embarassed",
    "embarrassed",
    "empathetic",
    "empowered",
    "empty",
    "enchanted",
    "encouraged",
    "energetic",
    "energized",
    "enlightened",
    "enraged",
    "enriched",
    "entertained",
    "enthralled",
    "enthusiastic",
    "envious",
    "erudite",
    "evasive",
    "evil",
    "exasperated",
    "excited",
    "excluded",
    "exhausted",
    "exhilarated",
    "expectant",
    "exploited",
    "exposed",
    "exuberant",
    "faithful",
    "fake",
    "fanciful",
    "fantastic",
    "fatalistic",
    "fatigued",
    "fearful",
    "fearless",
    "feisty",
    "fine",
    "flirty",
    "flustered",
    "foolish",
    "foreboding",
    "forgiven",
    "forgiving",
    "forgotten",
    "forthright",
    "fortunate",
    "framed",
    "frantic",
    "free",
    "friendly",
    "frightened",
    "frisky",
    "frustrated",
    "fulfilled",
    "full",
    "funny",
    "furious",
    "futile",
    "geeky",
    "generous",
    "gentle",
    "giddy",
    "giggly",
    "giving",
    "glad",
    "gloomy",
    "glorious",
    "good",
    "grateful",
    "great",
    "grieving",
    "groggy",
    "grouchy",
    "grumpy",
    "guarded",
    "guilty",
    "gullible",
    "handicapped",
    "happy",
    "harmonious",
    "hateful",
    "haughty",
    "haunted",
    "haunting",
    "healthy",
    "heard",
    "heartbroken",
    "heavy-hearted",
    "helpful",
    "helpless",
    "hesitant",
    "high",
    "honored",
    "hopeful",
    "hopeless",
    "horrible",
    "horrified",
    "hospitable",
    "hostile",
    "hot",
    "humble",
    "humiliated",
    "hungry",
    "hurt",
    "hyper",
    "hysterical",
    "idealistic",
    "idiotic",
    "idyllic",
    "ignorant",
    "ignored",
    "imaginative",
    "immune",
    "impatient",
    "impelled",
    "imperfect",
    "impertinent",
    "important",
    "impressed",
    "impulsive",
    "inadequate",
    "inattentive",
    "incensed",
    "inclusive",
    "incompetent",
    "incomplete",
    "incredulous",
    "indebted",
    "indecisive",
    "independent",
    "indescribable",
    "indifferent",
    "indignant",
    "industrious",
    "inept",
    "inferior",
    "inflated",
    "informed",
    "infuriated",
    "inhibited",
    "innocent",
    "innovative",
    "inquisitive",
    "insane",
    "insecure",
    "insensitive",
    "insidious",
    "insignificant",
    "insulted",
    "intense",
    "interested",
    "interrogated",
    "interrupted",
    "intimate",
    "intimidated",
    "intrigued",
    "invigorated",
    "invisible",
    "involved",
    "irate",
    "irked",
    "irrational",
    "irresponsible",
    "irritated",
    "isolated",
    "jaded",
    "jealous",
    "jinxed",
    "jolly",
    "jovial",
    "joyful",
    "joyous",
    "jubilant",
    "judged",
    "judgmental",
    "jumpy",
    "just",
    "justified",
    "kidded",
    "kind",
    "knowledgeable",
    "late",
    "lazy",
    "leery",
    "left",
    "let",
    "lethargic",
    "liable",
    "liberated",
    "liberating",
    "lifeless",
    "light-hearted",
    "liked",
    "listened",
    "listless",
    "logical",
    "lonely",
    "loose",
    "lost",
    "lousy",
    "lovable",
    "loved",
    "loving",
    "lucky",
    "lyrical",
    "mad",
    "malicious",
    "manipulated",
    "matter",
    "fact",
    "mean",
    "meditative",
    "melancholic",
    "melancholy",
    "mellow",
    "merciless",
    "merry",
    "mischievous",
    "miserable",
    "misinterpreted",
    "mistreated",
    "misunderstood",
    "mixed",
    "mocked",
    "mocking",
    "modest",
    "molested",
    "moody",
    "morose",
    "motivated",
    "mournful",
    "moved",
    "mystified",
    "naive",
    "nasty",
    "naughty",
    "nauseated",
    "needed",
    "needy",
    "negative",
    "neglected",
    "nerdy",
    "nervous",
    "neurotic",
    "nightmarish",
    "nonchalant",
    "nostalgic",
    "not",
    "specified",
    "noticed",
    "numb",
    "obeyed",
    "objective",
    "obligated",
    "obvious",
    "odd",
    "offended",
    "okay",
    "old",
    "open",
    "oppressed",
    "optimistic",
    "ornery",
    "control",
    "outraged",
    "overcome",
    "overjoyed",
    "overloaded",
    "overwhelmed",
    "overworked",
    "owned",
    "painful",
    "pampered",
    "panicky",
    "paralyzed",
    "passionate",
    "passive",
    "patient",
    "patronizing",
    "peaceful",
    "peeved",
    "pensive",
    "perky",
    "perplexed",
    "persecuted",
    "pessimistic",
    "pestered",
    "petrified",
    "petty",
    "phony",
    "pious",
    "pissed",
    "off",
    "playful",
    "pleased",
    "poor",
    "positive",
    "possessive",
    "powerful",
    "powerless",
    "practical",
    "predatory",
    "pressured",
    "private",
    "productive",
    "protected",
    "protective",
    "proud",
    "provoked",
    "prudish",
    "punished",
    "pushy",
    "puzzled",
    "questioned",
    "quiet",
    "quixotic",
    "quizzical",
    "rambunctious",
    "realistic",
    "reassured",
    "rebellious",
    "reborn",
    "receptive",
    "reckless",
    "recognized",
    "reconciled",
    "recumbent",
    "reflective",
    "refreshed",
    "regretful",
    "rejected",
    "rejuvenated",
    "relaxed",
    "released",
    "relieved",
    "reluctant",
    "reminiscent",
    "remorse",
    "renewed",
    "replaced",
    "replenished",
    "repressed",
    "rescued",
    "resentful",
    "reserved",
    "resistant",
    "resourceful",
    "respected",
    "responsible",
    "restless",
    "restricted",
    "revengeful",
    "reverent",
    "revitalized",
    "ribald",
    "rich",
    "ridicule",
    "ridiculous",
    "right",
    "rigid",
    "robbed",
    "romantic",
    "rotten",
    "rushed",
    "sabotaged",
    "sad",
    "safe",
    "sarcastic",
    "sardonic",
    "sassy",
    "satiated",
    "satiric",
    "satisfied",
    "saved",
    "scared",
    "scolded",
    "scorned",
    "secure",
    "seductive",
    "selfish",
    "self-assured",
    "self-centered",
    "self-confident",
    "self-conscious",
    "self-destructive",
    "self-reliant",
    "sensitive",
    "sentimental",
    "serene",
    "serious",
    "sexy",
    "shaken",
    "shamed",
    "sheepish",
    "shocked",
    "shunned",
    "shy",
    "sick",
    "silenced",
    "silly",
    "sincere",
    "sinful",
    "skeptical",
    "skillful",
    "slandered",
    "sleepy",
    "sluggish",
    "small",
    "smart",
    "smothered",
    "solemn",
    "somber",
    "soothed",
    "sorry",
    "special",
    "spiteful",
    "splendid",
    "spunky",
    "squashed",
    "stifled",
    "stimulated",
    "stingy",
    "strained",
    "stressed",
    "stretched",
    "strong",
    "stubborn",
    "stumped",
    "stunned",
    "stupid",
    "submissive",
    "successful",
    "suffocated",
    "suicidal",
    "sullen",
    "sunk",
    "super",
    "superior",
    "supported",
    "sure",
    "surly",
    "surprised",
    "suspenseful",
    "suspicious",
    "sympathetic",
    "tacky",
    "tactful",
    "talented",
    "talkative",
    "tame",
    "tarnished",
    "tasteful",
    "tearful",
    "teased",
    "tenacious",
    "tender",
    "tense",
    "tepid",
    "terrible",
    "terrific",
    "terrified",
    "terrifying",
    "tested",
    "testy",
    "thankful",
    "thoughtful",
    "threatened",
    "threatening",
    "thrifty",
    "thrilled",
    "tired",
    "tormented",
    "torn",
    "tortured",
    "touched",
    "tough",
    "tragic",
    "tranquil",
    "transformed",
    "trapped",
    "treasured",
    "trembly",
    "tremendous",
    "tricked",
    "troubled",
    "trusted",
    "trustful",
    "ugly",
    "unaccepted",
    "unappreciated",
    "unbalanced",
    "unburdened",
    "uncanny",
    "uncomfortable",
    "unconcerned",
    "uneven",
    "unfit",
    "unfriendly",
    "united",
    "unjust",
    "unknown",
    "unneeded",
    "unpleasant",
    "unreal",
    "unruly",
    "unwise",
    "up",
    "uplifted",
    "used",
    "useless",
    "vacant",
    "vague",
    "vain",
    "valid",
    "valued",
    "vengeful",
    "vexed",
    "vicious",
    "victimized",
    "victorious",
    "violated",
    "violent",
    "vivacious",
    "vivid",
    "void",
    "wacky",
    "warlike",
    "warm",
    "warmhearted",
    "warned",
    "wary",
    "wasted",
    "weak",
    "wealthy",
    "weary",
    "weird",
    "welcoming",
    "whimsical",
    "whole",
    "wild",
    "willful",
    "wishful",
    "witty",
    "worldly",
    "worried",
    "worse",
    "worthy",
    "wounded",
    "wrong",
    "yearning",
    "yellow",
    "yielding",
    "young",
    "youthful",
    "zany",
    "zealous"
]
