VERBS = [
  "accept",
  "accepted",
  "add",
  "added",
  "admire",
  "admired",
  "admit",
  "admitted",
  "advise",
  "advised",
  "afford",
  "afforded",
  "agree",
  "agreed",
  "alert",
  "alerted",
  "allow",
  "allowed",
  "amuse",
  "amused",
  "analyse",
  "analysed",
  "announce",
  "announced",
  "annoy",
  "annoyed",
  "answer",
  "answered",
  "apologise",
  "apologised",
  "appear",
  "appeared",
  "applaud",
  "applauded",
  "appreciate",
  "appreciated",
  "approve",
  "approved",
  "argue",
  "argued",
  "arrange",
  "arranged",
  "arrest",
  "arrested",
  "arrive",
  "arrived",
  "ask",
  "asked",
  "attach",
  "attached",
  "attack",
  "attacked",
  "attempt",
  "attempted",
  "attend",
  "attended",
  "attract",
  "attracted",
  "avoid",
  "avoided",
  "back",
  "backed",
  "bake",
  "baked",
  "balance",
  "balanced",
  "ban",
  "bang",
  "banged",
  "banned",
  "bare",
  "bared",
  "bat",
  "bathe",
  "bathed",
  "batted",
  "battle",
  "battled",
  "beam",
  "beamed",
  "beg",
  "begged",
  "behave",
  "behaved",
  "belong",
  "belonged",
  "bleach",
  "bleached",
  "bless",
  "blessed",
  "blind",
  "blinded",
  "blink",
  "blinked",
  "blot",
  "blotted",
  "blush",
  "blushed",
  "boast",
  "boasted",
  "boil",
  "boiled",
  "bolt",
  "bolted",
  "bomb",
  "bombed",
  "book",
  "booked",
  "bore",
  "bored",
  "borrow",
  "borrowed",
  "bounce",
  "bounced",
  "bow",
  "bowed",
  "box",
  "boxed",
  "brake",
  "braked",
  "branch",
  "branched",
  "breathe",
  "breathed",
  "bruise",
  "bruised",
  "brush",
  "brushed",
  "bubble",
  "bubbled",
  "bump",
  "bumped",
  "buried",
  "burn",
  "burned",
  "bury",
  "buzz",
  "buzzed",
  "calculate",
  "calculated",
  "call",
  "called",
  "camp",
  "camped",
  "care",
  "cared",
  "carried",
  "carry",
  "carve",
  "carved",
  "cause",
  "caused",
  "challenge",
  "challenged",
  "change",
  "changed",
  "charge",
  "charged",
  "chase",
  "chased",
  "cheat",
  "cheated",
  "check",
  "checked",
  "cheer",
  "cheered",
  "chew",
  "chewed",
  "choke",
  "choked",
  "chop",
  "chopped",
  "claim",
  "claimed",
  "clap",
  "clapped",
  "clean",
  "cleaned",
  "clear",
  "cleared",
  "clip",
  "clipped",
  "close",
  "closed",
  "coach",
  "coached",
  "coil",
  "coiled",
  "collect",
  "collected",
  "colour",
  "coloured",
  "comb",
  "combed",
  "command",
  "commanded",
  "communicate",
  "communicated",
  "compare",
  "compared",
  "compete",
  "competed",
  "complain",
  "complained",
  "complete",
  "completed",
  "concentrate",
  "concentrated",
  "concern",
  "concerned",
  "confess",
  "confessed",
  "confuse",
  "confused",
  "connect",
  "connected",
  "consider",
  "considered",
  "consist",
  "consisted",
  "contain",
  "contained",
  "continue",
  "continued",
  "copied",
  "copy",
  "correct",
  "corrected",
  "cough",
  "coughed",
  "count",
  "counted",
  "cover",
  "covered",
  "crack",
  "cracked",
  "crash",
  "crashed",
  "crawl",
  "crawled",
  "cried",
  "cross",
  "crossed",
  "crush",
  "crushed",
  "cry",
  "cure",
  "cured",
  "curl",
  "curled",
  "curve",
  "curved",
  "cycle",
  "cycled",
  "dam",
  "damage",
  "damaged",
  "dammed",
  "dance",
  "danced",
  "dare",
  "dared",
  "decay",
  "decayed",
  "deceive",
  "deceived",
  "decide",
  "decided",
  "decorate",
  "decorated",
  "delay",
  "delayed",
  "delight",
  "delighted",
  "deliver",
  "delivered",
  "depend",
  "depended",
  "describe",
  "described",
  "desert",
  "deserted",
  "deserve",
  "deserved",
  "destroy",
  "destroyed",
  "detect",
  "detected",
  "develop",
  "developed",
  "disagree",
  "disagreed",
  "disappear",
  "disappeared",
  "disapprove",
  "disapproved",
  "disarm",
  "disarmed",
  "discover",
  "discovered",
  "dislike",
  "disliked",
  "divide",
  "divided",
  "double",
  "doubled",
  "doubt",
  "doubted",
  "drag",
  "dragged",
  "drain",
  "drained",
  "dream",
  "dreamed",
  "dress",
  "dressed",
  "dried",
  "drip",
  "dripped",
  "drop",
  "dropped",
  "drown",
  "drowned",
  "drum",
  "drummed",
  "dry",
  "dust",
  "dusted",
  "earn",
  "earned",
  "educate",
  "educated",
  "embarrass",
  "embarrassed",
  "employ",
  "employed",
  "emptied",
  "empty",
  "encourage",
  "encouraged",
  "end",
  "ended",
  "enjoy",
  "enjoyed",
  "enter",
  "entered",
  "entertain",
  "entertained",
  "escape",
  "escaped",
  "examine",
  "examined",
  "excite",
  "excited",
  "excuse",
  "excused",
  "exercise",
  "exercised",
  "exist",
  "existed",
  "expand",
  "expand",
  "expect",
  "expected",
  "explain",
  "explained",
  "explode",
  "exploded",
  "extend",
  "extended",
  "face",
  "faced",
  "fade",
  "faded",
  "fail",
  "failed",
  "fancied",
  "fancy",
  "fasten",
  "fastened",
  "fax",
  "faxed",
  "fear",
  "feared",
  "fence",
  "fenced",
  "fetch",
  "fetched",
  "file",
  "filed",
  "fill",
  "filled",
  "film",
  "filmed",
  "fire",
  "fired",
  "fit",
  "fitted",
  "fix",
  "fixed",
  "flap",
  "flapped",
  "flash",
  "flashed",
  "float",
  "floated",
  "flood",
  "flooded",
  "flow",
  "fly",
  "flowed",
  "flower",
  "flowered",
  "fold",
  "folded",
  "follow",
  "followed",
  "fool",
  "fooled",
  "force",
  "forced",
  "form",
  "formed",
  "found",
  "founded",
  "frame",
  "framed",
  "fried",
  "frighten",
  "frightened",
  "fry",
  "gather",
  "gathered",
  "gaze",
  "gazed",
  "glow",
  "glowed",
  "glue",
  "glued",
  "grab",
  "grabbed",
  "grate",
  "grated",
  "grease",
  "greased",
  "greet",
  "greeted",
  "grin",
  "grinned",
  "grip",
  "gripped",
  "groan",
  "groaned",
  "guarantee",
  "guaranteed",
  "guard",
  "guarded",
  "guess",
  "guessed",
  "guide",
  "guided",
  "hammer",
  "hammered",
  "hand",
  "handed",
  "handle",
  "handled",
  "hang",
  "happen",
  "happened",
  "harass",
  "harassed",
  "harm",
  "harmed",
  "hate",
  "hated",
  "haunt",
  "haunted",
  "head",
  "headed",
  "heal",
  "healed",
  "heap",
  "heaped",
  "heat",
  "heated",
  "help",
  "helped",
  "hook",
  "hooked",
  "hop",
  "hope",
  "hoped",
  "hopped",
  "hover",
  "hovered",
  "hug",
  "hugged",
  "hum",
  "hummed",
  "hung",
  "hunt",
  "hunted",
  "hurried",
  "hurry",
  "identified",
  "identify",
  "ignore",
  "ignored",
  "imagine",
  "imagined",
  "impress",
  "impressed",
  "improve",
  "improved",
  "include",
  "included",
  "increase",
  "increased",
  "influence",
  "influenced",
  "inform",
  "informed",
  "inject",
  "injected",
  "injure",
  "injured",
  "instruct",
  "instructed",
  "intend",
  "intended",
  "interest",
  "interested",
  "interfere",
  "interfered",
  "interrupt",
  "interrupted",
  "introduce",
  "introduced",
  "invent",
  "invented",
  "invite",
  "invited",
  "irritate",
  "irritated",
  "itch",
  "itched",
  "jail",
  "jailed",
  "jam",
  "jammed",
  "jog",
  "jogged",
  "join",
  "joined",
  "joke",
  "joked",
  "judge",
  "judged",
  "juggle",
  "juggled",
  "jump",
  "jumped",
  "kick",
  "kicked",
  "kill",
  "killed",
  "kiss",
  "kissed",
  "kneel",
  "knelt",
  "knit",
  "knitted",
  "knock",
  "knocked",
  "knot",
  "knotted",
  "label",
  "labelled",
  "land",
  "landed",
  "last",
  "lasted",
  "laugh",
  "laughed",
  "launch",
  "launched",
  "learn",
  "learned",
  "level",
  "levelled",
  "license",
  "licensed",
  "lick",
  "licked",
  "lie",
  "lied",
  "lighten",
  "lightened",
  "like",
  "liked",
  "list",
  "listed",
  "listen",
  "listened",
  "live",
  "lived",
  "load",
  "loaded",
  "lock",
  "locked",
  "long",
  "longed",
  "look",
  "look",
  "love",
  "loved",
  "man",
  "manage",
  "managed",
  "manned",
  "march",
  "marched",
  "mark",
  "marked",
  "married",
  "marry",
  "match",
  "matched",
  "mate",
  "mated",
  "matter",
  "mattered",
  "measure",
  "measured",
  "meddle",
  "meddled",
  "melt",
  "melted",
  "memorise",
  "memorised",
  "mend",
  "mended",
  "mess",
  "messed",
  "milk",
  "milked",
  "mine",
  "mined",
  "miss",
  "missed",
  "mix",
  "mixed",
  "moan",
  "moaned",
  "moor",
  "moored",
  "mourn",
  "mourned",
  "move",
  "moved",
  "muddle",
  "muddled",
  "mug",
  "mugged",
  "multiplied",
  "multiply",
  "murder",
  "murdered",
  "nail",
  "nailed",
  "name",
  "named",
  "need",
  "needed",
  "nest",
  "nested",
  "nod",
  "nodded",
  "note",
  "noted",
  "notice",
  "noticed",
  "number",
  "numbered",
  "obey",
  "obeyed",
  "object",
  "objected",
  "observe",
  "observed",
  "obtain",
  "obtained",
  "occur",
  "occurred",
  "offend",
  "offended",
  "offer",
  "offered",
  "open",
  "opened",
  "order",
  "ordered",
  "overflow",
  "overflowed",
  "owe",
  "owed",
  "own",
  "owned",
  "pack",
  "packed",
  "paddle",
  "paddled",
  "paint",
  "painted",
  "park",
  "parked",
  "part",
  "parted",
  "pass",
  "passed",
  "paste",
  "pasted",
  "pat",
  "patted",
  "pause",
  "paused",
  "peck",
  "pecked",
  "pedal",
  "pedalled",
  "peel",
  "peeled",
  "peep",
  "peeped",
  "perform",
  "performed",
  "permit",
  "permitted",
  "phone",
  "phoned",
  "pick",
  "picked",
  "pinch",
  "pinched",
  "pine",
  "pined",
  "place",
  "placed",
  "plan",
  "planned",
  "plant",
  "planted",
  "play",
  "played",
  "please",
  "pleased",
  "plug",
  "plugged",
  "point",
  "pointed",
  "poke",
  "poked",
  "polish",
  "polished",
  "pop",
  "popped",
  "possess",
  "possessed",
  "post",
  "posted",
  "pour",
  "poured",
  "practise",
  "practised",
  "pray",
  "prayed",
  "preach",
  "preached",
  "precede",
  "preceded",
  "prefer",
  "preferred",
  "prepare",
  "prepared",
  "present",
  "presented",
  "preserve",
  "preserved",
  "press",
  "pressed",
  "pretend",
  "pretended",
  "prevent",
  "prevented",
  "prick",
  "pricked",
  "print",
  "printed",
  "produce",
  "produced",
  "program",
  "programmed",
  "promise",
  "promised",
  "protect",
  "protected",
  "provide",
  "provided",
  "pull",
  "pulled",
  "pump",
  "pumped",
  "punch",
  "punched",
  "puncture",
  "punctured",
  "punish",
  "punished",
  "push",
  "pushed",
  "question",
  "questioned",
  "questioned",
  "queue",
  "race",
  "raced",
  "radiate",
  "radiated",
  "rain",
  "rained",
  "raise",
  "raised",
  "reach",
  "reached",
  "realise",
  "realised",
  "receive",
  "received",
  "recognise",
  "recognised",
  "record",
  "recorded",
  "reduce",
  "reduced",
  "reflect",
  "reflected",
  "refuse",
  "refused",
  "regret",
  "regretted",
  "reign",
  "reigned",
  "reject",
  "rejected",
  "rejoice",
  "rejoiced",
  "relax",
  "relaxed",
  "release",
  "released",
  "relied",
  "rely",
  "remain",
  "remained",
  "remember",
  "remembered",
  "remind",
  "reminded",
  "remove",
  "removed",
  "repair",
  "repaired",
  "repeat",
  "repeated",
  "replace",
  "replaced",
  "replied",
  "reply",
  "report",
  "reported",
  "reproduce",
  "reproduced",
  "request",
  "requested",
  "rescue",
  "rescued",
  "retire",
  "retired",
  "return",
  "returned",
  "rhyme",
  "rhyme",
  "rinse",
  "rinsed",
  "risk",
  "risked",
  "rob",
  "robbed",
  "rock",
  "rocked",
  "roll",
  "rolled",
  "rot",
  "rotted",
  "rub",
  "rubbed",
  "ruin",
  "ruined",
  "rule",
  "ruled",
  "rush",
  "rushed",
  "run",
  "sack",
  "sacked",
  "sail",
  "sailed",
  "satisfied",
  "satisfy",
  "save",
  "saved",
  "saw",
  "sawed",
  "scare",
  "scared",
  "scatter",
  "scattered",
  "scold",
  "scolded",
  "scorch",
  "scorched",
  "scrape",
  "scraped",
  "scratch",
  "scratched",
  "scream",
  "screamed",
  "screw",
  "screwed",
  "scribble",
  "scribbled",
  "scrub",
  "scrubbed",
  "seal",
  "sealed",
  "search",
  "searched",
  "separate",
  "separate",
  "serve",
  "served",
  "settle",
  "settled",
  "shade",
  "shaded",
  "share",
  "shared",
  "shave",
  "shaved",
  "shelter",
  "sheltered",
  "shiver",
  "shivered",
  "shock",
  "shocked",
  "shop",
  "shopped",
  "shrug",
  "shrugged",
  "sigh",
  "sighed",
  "sign",
  "signal",
  "signalled",
  "signed",
  "sin",
  "sinned",
  "sip",
  "sipped",
  "ski",
  "skied",
  "skip",
  "skipped",
  "slap",
  "slapped",
  "slip",
  "slipped",
  "slow",
  "slowed",
  "smash",
  "smashed",
  "smell",
  "smelled",
  "smile",
  "smiled",
  "smoke",
  "smoked",
  "snatch",
  "snatched",
  "sneeze",
  "sneezed",
  "sniff",
  "sniffed",
  "snore",
  "snored",
  "snow",
  "snowed",
  "soak",
  "soaked",
  "soothe",
  "soothed",
  "sound",
  "sounded",
  "spare",
  "spared",
  "spark",
  "sparked",
  "sparkle",
  "sparkled",
  "spell",
  "spelled",
  "spill",
  "spilled",
  "spoil",
  "spoiled",
  "spot",
  "spotted",
  "spray",
  "sprayed",
  "sprout",
  "sprouted",
  "squash",
  "squashed",
  "squeak",
  "squeaked",
  "squeal",
  "squealed",
  "squeeze",
  "squeezed",
  "stain",
  "stained",
  "stamp",
  "stamped",
  "stare",
  "stared",
  "start",
  "started",
  "stay",
  "stayed",
  "steer",
  "steered",
  "step",
  "stepped",
  "stir",
  "stirred",
  "stitch",
  "stitched",
  "stop",
  "stopped",
  "store",
  "stored",
  "strap",
  "strapped",
  "strengthen",
  "strengthened",
  "stretch",
  "stretched",
  "strip",
  "stripped",
  "stroke",
  "stroked",
  "stuff",
  "stuffed",
  "subtract",
  "subtracted",
  "succeed",
  "succeeded",
  "suck",
  "sucked",
  "suffer",
  "suffered",
  "suggest",
  "suggested",
  "suit",
  "suited",
  "supplied",
  "supply",
  "support",
  "supported",
  "suppose",
  "supposed",
  "surprise",
  "surprised",
  "surround",
  "surrounded",
  "suspect",
  "suspected",
  "suspend",
  "suspended",
  "switch",
  "switched",
  "talk",
  "talked",
  "tame",
  "tamed",
  "tap",
  "tapped",
  "taste",
  "tasted",
  "tease",
  "teased",
  "telephone",
  "telephoned",
  "tempt",
  "tempted",
  "terrified",
  "terrify",
  "test",
  "tested",
  "thank",
  "thanked",
  "thaw",
  "thawed",
  "tick",
  "ticked",
  "tickle",
  "tickled",
  "tie",
  "tied",
  "time",
  "timed",
  "tip",
  "tipped",
  "tire",
  "tired",
  "touch",
  "touched",
  "tour",
  "toured",
  "tow",
  "towed",
  "trace",
  "traced",
  "trade",
  "traded",
  "train",
  "trained",
  "transport",
  "transported",
  "trap",
  "trapped",
  "travel",
  "travelled",
  "treat",
  "treated",
  "tremble",
  "trembled",
  "trick",
  "tricked",
  "tried",
  "trip",
  "tripped",
  "trot",
  "trotted",
  "trouble",
  "troubled",
  "trust",
  "trusted",
  "try",
  "tug",
  "tugged",
  "tumble",
  "tumbled",
  "turn",
  "turned",
  "twist",
  "twisted",
  "type",
  "typed",
  "undress",
  "undressed",
  "unfasten",
  "unfastened",
  "unite",
  "united",
  "unlock",
  "unlocked",
  "unpack",
  "unpacked",
  "untidied",
  "untidy",
  "use",
  "used",
  "vanish",
  "vanished",
  "visit",
  "visited",
  "wail",
  "wailed",
  "wait",
  "waited",
  "walk",
  "walked",
  "wander",
  "wandered",
  "want",
  "wanted",
  "warm",
  "warmed",
  "warn",
  "warned",
  "wash",
  "washed",
  "waste",
  "wasted",
  "watch",
  "watched",
  "water",
  "watered",
  "wave",
  "waved",
  "weigh",
  "weighed",
  "welcome",
  "welcomed",
  "whine",
  "whined",
  "whip",
  "whipped",
  "whirl",
  "whirled",
  "whisper",
  "whispered",
  "whistle",
  "whistled",
  "wink",
  "winked",
  "wipe",
  "wiped",
  "wish",
  "wished",
  "wobble",
  "wobbled",
  "wonder",
  "wondered",
  "work",
  "worked",
  "worried",
  "worry",
  "wrap",
  "wrapped",
  "wreck",
  "wrecked",
  "wrestle",
  "wrestled",
  "wriggle",
  "wriggled",
  "yawn",
  "yawned",
  "yell",
  "yelled",
  "zip",
  "zipped",
  "zoom",
  "zoomed"
]
