NOUNS = [
  "outpost",
  "plaza",
  "affinity",
  "residency",
  "spaghetti",
  "crow",
  "reinstatement",
  "forefront",
  "boldness",
  "repository",
  "syndrome",
  "vampire",
  "moose",
  "devolution",
  "announcement",
  "mutation",
  "likeness",
  "zebra",
  "confidant",
  "coaster",
  "rhododendron",
  "crossroads",
  "deflation",
  "oryx",
  "rubbing",
  "ballet",
  "lordship",
  "nutrition",
  "framework",
  "conspiracy",
  "scissors",
  "gnu",
  "gallery",
  "countryman",
  "longevity",
  "dexterity",
  "publicist",
  "sage",
  "mainframe",
  "condominium",
  "assembly",
  "drumming",
  "building",
  "piles",
  "obscurity",
  "vogue",
  "vegetation",
  "allotment",
  "carrier",
  "glucose",
  "nightmare",
  "delirium",
  "nervousness",
  "dialect",
  "observer",
  "consist",
  "restaurant",
  "beginner",
  "stimulus",
  "friendliness",
  "defection",
  "irrigation",
  "parrot",
  "monarchy",
  "violation",
  "hello",
  "embodiment",
  "dioxide",
  "lighting",
  "instruction",
  "horseman",
  "bluebell",
  "abstinence",
  "machinery",
  "emancipation",
  "overseer",
  "diagnosis",
  "ducking",
  "barrymore",
  "cartridge",
  "watchdog",
  "avarice",
  "association",
  "foyer",
  "patchwork",
  "poultry",
  "receptor",
  "bureaucracy",
  "snack",
  "fraud",
  "trilogy",
  "college",
  "firing",
  "cyclist",
  "iniquity",
  "mathematician",
  "intruder",
  "roadblock",
  "birthplace",
  "souvenir",
  "mythology",
  "counselor",
  "tendon",
  "ape",
  "distributor",
  "bullion",
  "rector",
  "drafting",
  "discovery",
  "metre",
  "interval",
  "badger",
  "rationality",
  "gallantry",
  "eyewitness",
  "cabbage",
  "intersection",
  "adultery",
  "demeanor",
  "intercession",
  "reader",
  "futility",
  "lineup",
  "shaving",
  "porpoise",
  "consultancy",
  "custard",
  "canary",
  "hedgehog",
  "scholarship",
  "slugger",
  "lion",
  "expediency",
  "cougar",
  "bonus",
  "success",
  "propensity",
  "terrier",
  "accounting",
  "molasses",
  "frigate",
  "reindeer",
  "novella",
  "turtle",
  "ratification",
  "regularity",
  "toad",
  "bomber",
  "transmitter",
  "tourist",
  "lynx",
  "terry",
  "dugout",
  "trout",
  "helplessness",
  "tourney",
  "adherence",
  "deer",
  "redistribution",
  "edelweiss",
  "artisan",
  "weariness",
  "actress",
  "outage",
  "persona",
  "chrysantemum",
  "unhappiness",
  "advert",
  "constable",
  "validity",
  "ambulance",
  "aesthetics",
  "campaign",
  "anemone",
  "actuality",
  "processor",
  "anemia",
  "emperor",
  "siding",
  "creator",
  "squid",
  "influx",
  "dishonesty",
  "maple",
  "despotism",
  "disarmament",
  "scouring",
  "cheerleader",
  "narration",
  "elements",
  "hyacinth",
  "hammock",
  "reaction",
  "bicycle",
  "crossover",
  "originality",
  "ocelot",
  "jenny",
  "allergy",
  "spectacle",
  "asthma",
  "comrade",
  "covering",
  "mouthful",
  "shopping",
  "feces",
  "error",
  "cyclone",
  "enlightenment",
  "hardship",
  "tendency",
  "goat",
  "seal",
  "bending",
  "cursor",
  "platypus",
  "monkey",
  "cat",
  "blossom",
  "greens",
  "redundancy",
  "dentist",
  "easter",
  "technology",
  "manifesto",
  "elk",
  "nourishment",
  "waitress",
  "ammonia",
  "tractor",
  "scrimmage",
  "mayer",
  "instructor",
  "conduit",
  "volcano",
  "underwear",
  "extinction",
  "ardor",
  "seizure",
  "sperm",
  "theater",
  "electricity",
  "llama",
  "plateau",
  "encouragement",
  "contractor",
  "correlation",
  "vindication",
  "coconut",
  "sheep",
  "absurdity",
  "frequency",
  "nexus",
  "exclamation",
  "aster",
  "recognition",
  "mongoose",
  "reformer",
  "sewing",
  "anthropology",
  "azalea",
  "heather",
  "pig",
  "hostility",
  "mango",
  "auspices",
  "handling",
  "environment",
  "battling",
  "madness",
  "accomplice",
  "lineage",
  "progression",
  "laurels",
  "sinking",
  "hibiscus",
  "feedback",
  "fundraiser",
  "digress",
  "koala",
  "saloon",
  "happiness",
  "weasel",
  "rendition",
  "snake",
  "bear",
  "sufferer",
  "captaincy",
  "gopher",
  "involvement",
  "potassium",
  "inactivity",
  "outing",
  "gorilla",
  "primrose",
  "dominion",
  "cumin",
  "investment",
  "posting",
  "armour",
  "caught",
  "leasing",
  "oracle",
  "header",
  "evacuation",
  "booty",
  "hamburger",
  "girlfriend",
  "hands",
  "iceberg",
  "melodrama",
  "schism",
  "opossum",
  "wildcat",
  "mechanics",
  "subcommittee",
  "earnestness",
  "housing",
  "bat",
  "storyteller",
  "peter",
  "begun",
  "airtime",
  "thunderstorm",
  "recipe",
  "horse",
  "lowry",
  "lodging",
  "thriller",
  "hog",
  "invasion",
  "hyena",
  "loathing",
  "victory",
  "advertising",
  "beaver",
  "seating",
  "acreage",
  "formality",
  "dedication",
  "ferocity",
  "misconception",
  "subsidy",
  "ascent",
  "pragmatism",
  "discord",
  "fluke",
  "coyote",
  "phrasing",
  "humility",
  "retirement",
  "tulip",
  "wolf",
  "boardroom",
  "locality",
  "mink",
  "oxygen",
  "banjo",
  "immunity",
  "hurricane",
  "interact",
  "thoroughfare",
  "setup",
  "redemption",
  "dossier",
  "gazelle",
  "detention",
  "suspension",
  "woodward",
  "chivalry",
  "formation",
  "proximity",
  "chipmunk",
  "variation",
  "broth",
  "physique",
  "bondage",
  "mahogany",
  "giraffe",
  "clearance",
  "doorway",
  "espionage",
  "mouse",
  "denomination",
  "envoy",
  "bergamot",
  "martin",
  "interpretation",
  "intermission",
  "pneumonia",
  "scenario",
  "enthusiasm",
  "legislation",
  "sorcery",
  "advertisement",
  "pharaoh",
  "artistry",
  "provider",
  "demonstration",
  "docking",
  "system",
  "dog",
  "attraction",
  "closeness",
  "allegiance",
  "vocalist",
  "logic",
  "publicity",
  "alligator",
  "buyout",
  "cutter",
  "words",
  "contentment",
  "completeness",
  "dealing",
  "lookout",
  "snail",
  "abbey",
  "pottery",
  "pasta",
  "syntax",
  "domination",
  "councilman",
  "tycoon",
  "climber",
  "otter",
  "blather",
  "reviewer",
  "breaker",
  "habitation",
  "buttercup",
  "stylus",
  "sweater",
  "phosphorus",
  "retention",
  "means",
  "toxicity",
  "supposition",
  "allies",
  "indecency",
  "mule",
  "rat",
  "mirth",
  "battery",
  "confiscation",
  "momentum",
  "peony",
  "proceeding",
  "annoyance",
  "baboon",
  "orientation",
  "barrister",
  "snark",
  "disability",
  "baron",
  "liberation",
  "degeneration",
  "allegory",
  "knocking",
  "specs",
  "dynamics",
  "indicator",
  "robber",
  "storey",
  "fox",
  "circus",
  "homeland",
  "boomer",
  "clutches",
  "repertoire",
  "privacy",
  "bird",
  "accuracy",
  "specimen",
  "prisoner",
  "rebirth",
  "meantime",
  "biography",
  "arrow",
  "chameleon",
  "pretense",
  "width",
  "resentment",
  "abundance",
  "depression",
  "marigold",
  "hacker",
  "china",
  "mover",
  "literature",
  "nationality",
  "schoolboy",
  "leopard",
  "carcass",
  "obscenity",
  "allocation",
  "layout",
  "kangaroo",
  "kingdom",
  "repayment",
  "vaccination",
  "aviation",
  "swimmer",
  "cropping",
  "seeder",
  "rosemary",
  "warthog",
  "reassurance",
  "threshold",
  "brewer",
  "suburb",
  "poker",
  "examination",
  "diver",
  "prophecy",
  "accommodation",
  "homer",
  "computing",
  "intolerance",
  "misunderstanding",
  "simulation",
  "altercation",
  "warmth",
  "anatomy",
  "standpoint",
  "outcome",
  "protein",
  "applause",
  "cornerstone",
  "eater",
  "whereabouts",
  "annuity",
  "advice",
  "woodchuck",
  "grouping",
  "refinery",
  "camel",
  "whiteness",
  "conflict",
  "republic",
  "runoff",
  "balls",
  "colleague",
  "equator",
  "buffalo",
  "eagerness",
  "liner",
  "damsel",
  "outfield",
  "maintenance",
  "resurgence",
  "squirrel",
  "drunkenness",
  "nobility",
  "amaranth",
  "pueblo",
  "mustang",
  "illustrator",
  "vanguard",
  "imprisonment",
  "outdoors",
  "sending",
  "stanza",
  "taker",
  "seduction",
  "reins",
  "drank",
  "backlash",
  "tuning",
  "encampment",
  "majority",
  "inaction",
  "ox",
  "corpus",
  "bookmark",
  "civilisation",
  "accreditation",
  "laborer",
  "function",
  "parson",
  "university",
  "jaguar",
  "medics",
  "parliament",
  "puberty",
  "functionality",
  "culprit",
  "ranger",
  "zinnia",
  "specification",
  "orchid",
  "broccoli",
  "mentality",
  "youngster",
  "rancher",
  "vulnerability",
  "ewe",
  "impala",
  "wombat",
  "colors",
  "commissioner",
  "unification",
  "semiconductor",
  "networking",
  "dumps",
  "disobedience",
  "priesthood",
  "genesis",
  "departure",
  "horror",
  "solitude",
  "viability",
  "vicinity",
  "bottlebrush",
  "flask",
  "lavender",
  "sharpness",
  "crocus",
  "deduction",
  "curfew",
  "daybreak",
  "retailer",
  "adage",
  "tossing",
  "sarcasm",
  "honesty",
  "grappling",
  "litre",
  "mobility",
  "sediment",
  "withholding",
  "onslaught",
  "lemur",
  "grocer",
  "metaphysics",
  "nursery",
  "licence",
  "delphinium",
  "saturday",
  "relaxation",
  "treadmill",
  "tuesday",
  "magnificence",
  "calamity",
  "operation",
  "staircase",
  "adoption",
  "witchcraft",
  "juncture",
  "inauguration",
  "environs",
  "celebrity",
  "chasm",
  "salvation",
  "driver",
  "ounce",
  "bowling",
  "illness",
  "basin",
  "inevitability",
  "rabbit",
  "squad",
  "quorum",
  "policeman",
  "exploitation",
  "provocation",
  "nobody",
  "ferret",
  "bedtime",
  "fulfillment",
  "wolverine",
  "manga",
  "wealth",
  "preoccupation",
  "grandeur",
  "mowing",
  "freesia",
  "certainty",
  "employment",
  "brightness",
  "probation",
  "stole",
  "tapir",
  "synopsis",
  "intercourse",
  "accountability",
  "posterity",
  "relativism",
  "jasmine",
  "burglary",
  "syrah",
  "ultimatum",
  "penguin",
  "roses",
  "commune",
  "differentiation",
  "inaccuracy",
  "donkey",
  "marjoram",
  "statement",
  "commenter",
  "tavern",
  "barrier",
  "hearts",
  "diploma",
  "miner",
  "whisky",
  "innovation",
  "hamster",
  "christianity",
  "hockey",
  "litigation",
  "narrator",
  "estimation",
  "parakeet",
  "mailing",
  "snapdragon",
  "publisher",
  "complexity",
  "headset",
  "scooter",
  "womanhood",
  "raccoon",
  "sunflower",
  "infiltration",
  "martyrdom",
  "duchess",
  "lily",
  "exaggeration",
  "violet",
  "somewhere",
  "ignition",
  "organisation",
  "stillness",
  "finale",
  "fixing",
  "cylinder",
  "oasis",
  "commander",
  "villa",
  "aardvark",
  "pairing",
  "heads",
  "babbling",
  "elephant",
  "ralph",
  "opposition",
  "mayor",
  "murderer",
  "juror",
  "subscription",
  "rhinoceros",
  "clearing",
  "staging",
  "sweepstakes",
  "tansy",
  "ligament",
  "memory",
  "fertilization",
  "immunization",
  "sloth",
  "camellias",
  "certification",
  "dismissal",
  "reptile",
  "absorption",
  "normalcy",
  "drilling",
  "traveler",
  "twenties",
  "shrew",
  "passenger",
  "gusto",
  "proceedings",
  "acceptance",
  "conversation",
  "semicolon",
  "appointment",
  "translation",
  "juggernaut",
  "iguana",
  "iris",
  "quilting",
  "appellation",
  "movie",
  "seriousness",
  "cheetah",
  "alpaca",
  "darkness",
  "ibex",
  "comer",
  "recurrence",
  "tights",
  "embroidery",
  "fascism",
  "mouthpiece",
  "bull",
  "baker",
  "browsing",
  "outset",
  "holly",
  "carnation",
  "billing",
  "senator",
  "stagnation",
  "attacker",
  "absence",
  "deficiency",
  "poster",
  "brunt",
  "cilantro",
  "scarcity",
  "refrigerator",
  "touchdown",
  "frog",
  "accessibility",
  "tempo",
  "foothold",
  "snapshot",
  "wiring",
  "biology",
  "uprising",
  "aversion",
  "adaptation",
  "orientalism",
  "appraisal",
  "salamander",
  "walrus",
  "apparatus",
  "distribution",
  "ticker",
  "vista",
  "contents",
  "downside",
  "architecture",
  "cow",
  "demon",
  "telephony",
  "bellflower",
  "fusion",
  "fries",
  "helping",
  "lilac",
  "deference",
  "dwelling",
  "enclosure",
  "coding",
  "prorogation",
  "fish",
  "thyme",
  "jackal",
  "misery",
  "illustration",
  "digger",
  "regulator",
  "puma",
  "advancement",
  "musician",
  "measurement",
  "consistency",
  "flashing",
  "panther",
  "joseph",
  "tracing",
  "prominence",
  "designation",
  "matrix",
  "offense",
  "forgiveness",
  "philosopher",
  "fastball",
  "archipelago",
  "formula",
  "soccer",
  "theology",
  "neighbour",
  "waistcoat",
  "negligence",
  "narcissus",
  "folklore",
  "rapidity",
  "matron",
  "anxiety",
  "collision",
  "windfall",
  "skate",
  "dominance",
  "mediator",
  "pundit",
  "chimpanzee",
  "resignation",
  "notification",
  "putting",
  "depletion",
  "lifeline",
  "atheism",
  "gunman",
  "larceny",
  "deliverance",
  "mantra",
  "orchestra",
  "endangerment",
  "earnings",
  "vomiting",
  "postponement",
  "headcount",
  "amaryllis",
  "verification",
  "bases",
  "allegation",
  "pounding",
  "genitals",
  "spectre",
  "innocence",
  "follower",
  "shoplifting",
  "transmission",
  "configuration",
  "radiance",
  "hoarding",
  "pendulum",
  "jogging",
  "consolidation",
  "cynicism",
  "begonia",
  "dispatcher",
  "aircraft",
  "arrears",
  "authority",
  "countdown",
  "editor",
  "archery",
  "glitter",
  "noodle",
  "reputation",
  "porcupine",
  "skunk",
  "daddy",
  "daisy",
  "crocodile",
  "pathos",
  "infamy",
  "catfish",
  "scrum",
  "sophistication",
  "yak",
  "daffodil",
  "marmoset",
  "freestyle",
  "groundwork",
  "boasting",
  "liquidation",
  "listener",
  "savior",
  "chili",
  "assignment",
  "workman",
  "riches",
  "wardrobe",
  "antelope",
  "motto",
  "breadth",
  "muskrat",
  "stamina",
  "lamb",
  "brainstorming",
  "mole",
  "lotus",
  "curator",
  "organizer",
  "capybara",
  "forefinger",
  "trauma",
  "spoiler",
  "therapy",
  "snead",
  "chinchilla",
  "saucer",
  "perusal",
  "thicket",
  "epilepsy",
  "cemetery",
  "panda",
  "basis",
  "nucleus",
  "voltage",
  "template",
  "sister",
  "mayhem",
  "cheesecake",
  "collaborator",
  "precedence",
  "method",
  "catholicism",
  "stocks",
  "anomaly",
  "height",
  "bonding",
  "insurer",
  "recreation",
  "widget",
  "blackberry",
  "lifeblood",
  "frenchman",
  "canonization",
  "jurisprudence",
  "fetish",
  "dingo",
  "criminality",
  "armadillo",
  "slipper",
  "underdog",
  "today",
  "definition",
  "monster",
  "columbine",
  "whale",
  "nylon",
  "mishap",
  "election",
  "clover",
  "finch",
  "brunch",
  "prospectus",
  "pointer",
  "inspiration",
  "nuisance",
  "paradox",
  "repentance",
  "scolding",
  "gladiolus",
  "dollar",
  "insanity",
  "chemotherapy",
  "commemoration",
  "civility",
  "falls",
  "plurality",
  "providence",
  "scenery",
  "consul",
  "orangutan",
  "dahlia",
  "morale",
  "standstill",
  "google",
  "bison",
  "hallway",
  "pullman",
  "dawning",
  "hegemony",
  "hierarchy",
  "mortality",
  "coverage",
  "recourse",
  "delegation",
  "jones",
  "lizard",
  "lustre",
  "brotherhood",
  "solemnity",
  "cabot",
  "righteousness",
  "quart",
  "owner",
  "apologise",
  "terror",
  "dromedary",
  "tyrant",
  "bounds",
  "polling",
  "appendix",
  "developer",
  "manufacturer",
  "patriotism",
  "speculation",
  "stairway",
  "concur",
  "viewpoint",
  "ram",
  "mimosa",
  "clothing",
  "leadership",
  "acquiescence",
  "schooner",
  "processing",
  "petunia",
  "apartheid",
  "helper",
  "equation",
  "doorstep",
  "gridlock",
  "simplicity",
  "hippopotamus",
  "permission",
  "rapport",
  "rocks",
  "servitude",
  "ankle",
  "effectiveness",
  "mandrill",
  "newt",
  "tablespoon",
  "agriculture",
  "hearth",
  "apostle",
  "delicacy",
  "cracker",
  "adjustment",
  "attractiveness",
  "fragmentation",
  "serenity",
  "bingo",
  "appeasement",
  "disservice",
  "opportunity",
  "footing",
  "reinforcement",
  "precinct",
  "cabal",
  "sesame",
  "prototype",
  "foxglove",
  "flora",
  "glamour",
  "clerk",
  "bones",
  "charade",
  "combustion",
  "competition",
  "heath",
  "rodeo",
  "diversity",
  "playing",
  "conflagration",
  "bodyguard",
  "quantity",
  "racism",
  "imperialism",
  "stoppage",
  "iteration",
  "projection",
  "eloquence",
  "neighborhood",
  "boar",
  "solicitation",
  "thistle",
  "comedian",
  "semifinal",
  "monument",
  "headquarters",
  "handshake",
  "tiger",
  "aggression",
  "parsley",
  "cassette",
  "pessimism",
  "plethora",
  "cholera"
]

ANIMALS = [
    "aardvark",
    "alligator",
    "alpaca",
    "antelope",
    "ape",
    "armadillo",
    "baboon",
    "badger",
    "bat",
    "bear",
    "beaver",
    "bison",
    "boar",
    "buffalo",
    "bull",
    "camel",
    "canary",
    "capybara",
    "cat",
    "chameleon",
    "cheetah",
    "chimpanzee",
    "chinchilla",
    "chipmunk",
    "cougar",
    "cow",
    "coyote",
    "crocodile",
    "crow",
    "deer",
    "dingo",
    "dog",
    "donkey",
    "dromedary",
    "elephant",
    "elk",
    "ewe",
    "ferret",
    "finch",
    "fish",
    "fox",
    "frog",
    "gazelle",
    "monster",
    "giraffe",
    "gnu",
    "goat",
    "gopher",
    "gorilla",
    "hamster",
    "hedgehog",
    "hippopotamus",
    "hog",
    "horse",
    "hyena",
    "ibex",
    "iguana",
    "impala",
    "jackal",
    "jaguar",
    "kangaroo",
    "koala",
    "lamb",
    "lemur",
    "leopard",
    "lion",
    "lizard",
    "llama",
    "lynx",
    "mandrill",
    "marmoset",
    "mink",
    "mole",
    "mongoose",
    "monkey",
    "moose",
    "mouse",
    "mule",
    "muskrat",
    "mustang",
    "bird",
    "newt",
    "ocelot",
    "opossum",
    "orangutan",
    "oryx",
    "otter",
    "ox",
    "panda",
    "panther",
    "parakeet",
    "parrot",
    "pig",
    "platypus",
    "porcupine",
    "porpoise",
    "puma",
    "rabbit",
    "raccoon",
    "ram",
    "rat",
    "reindeer",
    "reptile",
    "rhinoceros",
    "salamander",
    "seal",
    "sheep",
    "shrew",
    "skunk",
    "sloth",
    "snake",
    "squirrel",
    "tapir",
    "tiger",
    "toad",
    "turtle",
    "walrus",
    "warthog",
    "weasel",
    "whale",
    "wildcat",
    "wolf",
    "wolverine",
    "wombat",
    "woodchuck",
    "yak",
    "zebra"
]

FLOWERS = [
    "anemone",
    "amaryllis",
    "amaranth",
    "aster",
    "azalea",
    "begonia",
    "bellflower",
    "bergamot",
    "bluebell",
    "bottlebrush",
    "buttercup",
    "camellias",
    "carnation",
    "chrysantemum",
    "columbine",
    "clover",
    "crocus",
    "daisy",
    "dahlia",
    "daffodil",
    "delphinium",
    "edelweiss",
    "primrose",
    "foxglove",
    "freesia",
    "gladiolus",
    "hibiscus",
    "heather",
    "hyacinth",
    "holly",
    "iris",
    "jasmine",
    "slipper",
    "lavender",
    "lilac",
    "lily",
    "lotus",
    "marigold",
    "marjoram",
    "mimosa",
    "narcissus",
    "blossom",
    "orchid",
    "peony",
    "petunia",
    "rhododendron",
    "rosemary",
    "roses",
    "sage",
    "snapdragon",
    "sunflower",
    "tansy",
    "thistle",
    "thyme",
    "tulip",
    "violet",
    "lily",
    "zinnia"
]
